@@ -58,6 +58,8 @@ class GradeNotebooks():
 
 class BaseHandler(tornado.web.RequestHandler):
     def get_current_user(self):
+        u = self.get_secure_cookie("user")
+        log.write_logs("Check User", f"get user:{u}", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         return self.get_secure_cookie("user")
 
 class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
@@ -80,7 +82,7 @@ class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                             code=self.get_argument('code'))
             # Save the user with e.g. set_secure_cookie
             log.write_logs("6.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-            self.set_secure_cookie("user", user["id_token"])
+            self.set_secure_cookie("user", str(user))
             self.redirect("/")
         
 class Userform(tornado.web.RequestHandler,
